@@ -1,6 +1,6 @@
 #' @rdname loon2ggplot
 #' @export
-loon2ggplot.l_layer_histogram <- function(target, asAes = TRUE, ...) {
+loon2ggplot.l_layer_histogram <- function(target, asAes = TRUE, selectedOnTop = TRUE, ...) {
 
   widget <- loon::l_create_handle(attr(target, "widget"))
   ggObj <- list(...)$ggObj
@@ -43,6 +43,11 @@ loon2ggplot.l_layer_histogram <- function(target, asAes = TRUE, ...) {
     fill <- data$fill
     colour <- data$colour
 
+    if(!selectedOnTop)
+      warning("For histogram, if the `asAes` is set as FALSE, the plot will be created by adding layer `geom_rect()`. ",
+              "It is pointless to set the `selectedOnTop` as FALSE",
+              call. = FALSE)
+
     ggObj <- ggObj +
       ggplot2::geom_rect(
         data = data.frame(xmin = xmin,
@@ -101,8 +106,8 @@ histogramAsAesTRUE <- function(widget) {
   }
 
   # preserve the order
-  values <- hex2colorName(values)
-  activeColor <- hex2colorName(activeColor)
+  values <- l_colorName(values, error = FALSE)
+  activeColor <- l_colorName(activeColor, error = FALSE)
   activeColor <- factor(activeColor, levels = values)
 
   return(
