@@ -1,11 +1,11 @@
 #' @rdname loon2ggplot
 #' @export
-loon2ggplot.l_pairs <- function(target, asAes = TRUE, ...) {
+loon2ggplot.l_pairs <- function(target, asAes = TRUE, selectedOnTop = TRUE, ...) {
 
   locations <- g_getLocations(target)
 
   gm <- GGally::ggmatrix(
-    plots = g_getPlots(target, asAes = asAes),
+    plots = g_getPlots(target, asAes = asAes, selectedOnTop = selectedOnTop),
     nrow = locations$nrow,
     ncol = locations$ncol,
     byrow = FALSE,
